STATS_PREFIX = 'run_info'

STAR_SOLO_DIR = 'Solo.out'
STAR_GENE_DIR = 'Gene'
STAR_RAW_DIR = 'raw'
STAR_FILTERED_DIR = 'filtered'
STAR_VELOCYTO_DIR = 'Velocyto'
STAR_BAM_FILENAME = 'Aligned.sortedByCoord.out.bam'
STAR_BAI_FILENAME = 'Aligned.sortedByCoord.out.bai'
STAR_BARCODES_FILENAME = 'barcodes.tsv'
STAR_FEATURES_FILENAME = 'features.tsv'
STAR_MATRIX_FILENAME = 'matrix.mtx'

CONSENSUS_BAM_FILENAME = 'consensus.bam'

COUNT_DIR = 'count'
PARSE_DIR = '0_parse'
CONVS_FILENAME = 'convs.pkl.gz'
GENES_FILENAME = 'genes.pkl.gz'
CONVERSIONS_FILENAME = 'conversions.csv'
CONVERSIONS_INDEX_FILENAME = 'conversions.idx'
ALIGNMENTS_FILENAME = 'alignments.csv'

COVERAGE_FILENAME = 'coverage.csv'
COVERAGE_INDEX_FILENAME = 'coverage.idx'
SNPS_FILENAME = 'snps.csv'

COUNTS_PREFIX = 'counts'
ESTIMATE_DIR = 'estimate'
RATES_PREFIX = 'rates'
P_E_FILENAME = 'p_e.csv'
P_C_PREFIX = 'p_c'
AGGREGATE_FILENAME = 'aggregate.csv'

ADATA_FILENAME = 'adata.h5ad'
